from . import (
    code_blocks, headings, plain_summary, featured_image, media, tables,
    authors, outdated_article,
)


PLUGINS = [
    code_blocks, headings, plain_summary, featured_image, media, tables,
    authors, outdated_article
]
